#!/bin/bash
#
# Lattices-to-Landmarks Demo #1:
#   Pinch lattices,
#   add landmark-based pronunciation model,
#   align landmarks with words in the MAP path
#

if [ ]; then

# 1.  Create a landmarks version of pronlex
echo "*** CREATING DICTIONARY ***";
pronlex_dict=cfg/pronlex.dict  # standard phonemic pronlex dictionary
pronlex_feattab=cfg/pronlex-feattab.txt # Config file for phn2lm.pl
pronlex_splitphones=cfg/pronlex-splitphones.txt # Config file for phn2lm.pl
if [ ! -d dict ]; then mkdir dict; fi
echo dict2mlf.pl $pronlex_dict
dict2mlf.pl $pronlex_dict > dict/pronlex.mlf
echo phn2lm.pl $pronlex_feattab $pronlex_splitphones 
phn2lm.pl $pronlex_feattab $pronlex_splitphones < dict/pronlex.mlf > dict/pronlm.mlf
echo extractmlflayer.pl 1 3 
extractmlflayer.pl 1 3 < dict/pronlm.mlf > dict/tmp.mlf
echo mlf2dict.pl 
mlf2dict.pl dict/tmp.mlf > dict/pronlm.dict
 
# 2.  Split the input multi-utterance lattice into utterances
den_lattice=dvd/10937phone-HTK_MLFS+Hub5Cell-0-01.hlat-den-xw-ph;
num_lattice=dvd/10937phone-HTK_MLFS+Hub5Cell-0-01.hlat-num-xw-ph;
if [ ! -d denlat ]; then mkdir denlat; fi
cd denlat; split_lattice.pl ../$den_lattice; cd ..;
if [ ! -d numlat ]; then mkdir numlat; fi
cd numlat; split_lattice.pl ../$num_lattice; cd ..;

# 2.A   Create Praat transcriptions to show each lattice
for d in num den; do
 echo "*** LAT2PRAAT $d LOOP ***";
 if [ ! -d P${d}lat ]; then mkdir P${d}lat; fi
 ls ${d}lat | awk "{printf(\"${d}lat/%s P${d}lat/%s\n\",\$1,\$1);}" | sed 's/lat$/TextGrid/' > scp/P${d}lat.scp;
 lat2praat.pl scp/P${d}lat.scp
done

fi

# 3.  Pinch the lattices
for d in num den; do
 echo "*** PINCH_LATTICE $d LOOP ***";
 if [ ! -d pinch$d ]; then mkdir pinch$d; fi
 sed "s/P${d}lat/pinch$d/;s/TextGrid/lat/" scp/P${d}lat.scp  > scp/pinch$d.scp;
 pinch_lattice.pl scp/pinch${d}.scp;
done

# 3.A   Create Praat transcriptions to show each pinched lattice
for d in num den; do
 echo "*** LAT2PRAAT $d LOOP ***";
 if [ ! -d Ppinch${d} ]; then mkdir Ppinch${d}; fi 
 sed "s/P${d}lat/Ppinch$d/;s/${d}lat/pinch$d/" scp/P${d}lat.scp  > scp/Ppinch$d.scp;
 lat2praat.pl scp/Ppinch${d}.scp
done

# 4.  Add landmark pronunciation to edges in pinchden and pinchnum
for d in num den; do
 echo "*** AUGMENT_LATTICE $d LOOP ***";
 if [ ! -d aug$d ]; then mkdir aug$d; fi
 sed "s/pinch$d/aug$d/;s/${d}lat/pinch$d/" scp/pinch$d.scp  > scp/aug$d.scp;
 augment_lattice.pl scp/aug${d}.scp p=dict/pronlm.dict;
done

# 5.  Align edges
for d in num den; do
 echo "*** ALIGN_EDGES $d LOOP ***";
 if [ ! -d aln$d ]; then mkdir aln$d; fi
 sed "s/aug$d/aln$d/;s/pinch$d/aug$d/" scp/aug${d}.scp  > scp/aln$d.scp;
 align_edges.pl scp/aln${d}.scp
done

