#!/bin/bash
#
# Lattices-to-Landmarks Demo #2: 
#   Add landmark-based pronunciation to edges in graph,
#   break edges into syllable-edges,
#   dp-align them
#

# 1.  Create a landmarks version of pronlex
echo "*** CREATING DICTIONARY ***";
pronlex_dict=cfg/pronlex.dict  # standard phonemic pronlex dictionary
pronlex_feattab=cfg/pronlex-feattab.txt # Config file for phn2lm.pl
pronlex_splitphones=cfg/pronlex-splitphones.txt # Config file for phn2lm.pl
if [ ! -d dict ]; then mkdir dict; fi
echo dict2mlf.pl $pronlex_dict
dict2mlf.pl $pronlex_dict > dict/pronlex.mlf
echo phn2lm.pl $pronlex_feattab $pronlex_splitphones 
phn2lm.pl $pronlex_feattab $pronlex_splitphones < dict/pronlex.mlf > dict/pronlm.mlf
echo extractmlflayer.pl 1 3 
extractmlflayer.pl 1 3 < dict/pronlm.mlf > dict/tmp.mlf
echo mlf2dict.pl 
mlf2dict.pl dict/tmp.mlf > dict/pronlm.dict

if [ ]; then

# 2.  Split the input multi-utterance lattice into utterances
den_lattice=dvd/10937phone-HTK_MLFS+Hub5Cell-0-01.hlat-den-xw-ph;
num_lattice=dvd/10937phone-HTK_MLFS+Hub5Cell-0-01.hlat-num-xw-ph;
if [ ! -d denlat ]; then mkdir denlat; fi
cd denlat; split_lattice.pl ../$den_lattice; cd ..;
if [ ! -d numlat ]; then mkdir numlat; fi
cd numlat; split_lattice.pl ../$num_lattice; cd ..;

# 2.A   Create Praat transcriptions to show each lattice
for d in num den; do
 echo "*** LAT2PRAAT $d LOOP ***";
 if [ ! -d P${d}lat ]; then mkdir P${d}lat; fi
 ls ${d}lat | awk "{printf(\"${d}lat/%s P${d}lat/%s\n\",\$1,\$1);}" | sed 's/lat$/TextGrid/' | head -20 > scp/P${d}lat.scp;
 lat2praat.pl scp/P${d}lat.scp
done

fi

# 3.  Augment the lattices:
#     Add pronunciation model, and tag the MAP path
#
for d in num den; do
 echo "*** AUGMENT_LATTICE $d LOOP ***";
 if [ ! -d pn_$d ]; then mkdir pn_$d; fi
 sed "s/P${d}lat/pn_$d/;s/TextGrid/lat/" scp/P${d}lat.scp  > scp/pn_$d.scp;
 augment_lattice.pl scp/pn_${d}.scp p=dict/pronlm.dict n=1
done

# 4.   Syllabify the edges
for d in num den; do
 echo "*** SYLLABIFY_EDGES $d LOOP ***";
 if [ ! -d syl${d} ]; then mkdir syl${d}; fi 
 sed "s/pn_$d/syl$d/;s/${d}lat/pn_$d/" scp/pn_${d}.scp  > scp/syl$d.scp
 syllabify_edges.pl scp/syl$d.scp
done

# 5.   Divide the syllabified edges
for d in num den; do
 echo "*** DIVIDE_EDGES $d LOOP ***";
 if [ ! -d div${d} ]; then mkdir div${d}; fi 
 sed "s/syl$d/div$d/;s/pn_$d/syl$d/" scp/syl${d}.scp  > scp/div$d.scp
 divide_edges.pl ';:' scp/div$d.scp
done

# 5.A.  Create Praat transcriptions
for d in num den; do
 echo "*** LAT2PRAAT-DIV $d LOOP ***";
 if [ ! -d Pdiv${d} ]; then mkdir Pdiv${d}; fi 
 sed "s/syl$d/Pdiv$d/;s/pn_$d/div$d/;s/lat$/TextGrid/" scp/syl${d}.scp  > scp/Pdiv$d.scp
 lat2praat.pl scp/Pdiv$d.scp
done

# 6.   DP-Pinch the syllabified edges
for d in num den; do
 echo "*** DP_PINCH $d LOOP ***";
 if [ ! -d dpp${d} ]; then mkdir dpp${d}; fi 
 sed "s/syl$d/dpp$d/;s/pn_$d/div$d/" scp/syl${d}.scp  > scp/dpp$d.scp
 dp_pinch.pl scp/dpp$d.scp
done

# 6.A  Create Praat transcriptions
for d in num den; do
 echo "*** LAT2PRAAT-DPP $d LOOP ***";
 if [ ! -d Pdpp${d} ]; then mkdir Pdpp${d}; fi 
 sed "s/syl$d/Pdpp$d/;s/pn_$d/dpp$d/;s/lat$/TextGrid/" scp/syl${d}.scp  > scp/Pdpp$d.scp
 lat2praat.pl scp/Pdpp$d.scp
done

