#!/usr/bin/perl
# normalize_phn.pl: Mark Hasegawa-Johnson, October 2003
# Illinois Speech and Language Engineering (ISLE group)
#
# Usage text (printed if normalize_phn is called with any argument):
$USAGE=<<ENDUSAGE;

normalize_phn.pl: eliminate unused distinctions in an ICSI PHN MLF

Usage: normalize_phn.pl < input.mlf > output.mlf

The third word on each input line (the label, in an MLF file) is
subjected to a series of substitution regular expressions in order to
eliminate unused distinction.  For example, all modifiers in square
brackets or after _ are removed.  Double-quotes are removed.  These
rules should be easy to modify if you want to normalize your
transcriptions differently.

ENDUSAGE

################################################################
# Main program

if (@ARGV>0) { print STDERR $USAGE; exit; }

while($line = <STDIN>) {
  chop($line);
  @fields = split(/\s+/,$line);

  # If this is a time-time-label line, process it
  if($line =~ /(\d+)\s+(\d+)\s+(\S+)/) {
    # First, convert to lower case; most are, but a few aren't
    local $l = lc($fields[2]);
    
    # Eliminate various background noise notations
    $l =~ s/\bsil\b//;
    
    # These words mean silence even if extended, e.g. SILENCEDUETOSPLICE
    $l =~ s/.*(h\#|croff|unknown|click|silence|breath).*//;
    $l =~ s/.*(crosstalk|static|noise|smack|buzz|humm).*//;

    # Eliminate commentary between brackets, braces, or parentheses
    #  after underscore, or after ? or ! or # or +
    # This should come last, so that # doesn't keep H# from being used
    $l =~ s/\[.*\]//;
    $l =~ s/\(.*\)//;
    $l =~ s/\{.*\}//;
    $l =~ s/(_|\!|\?|\#|\+).*//;

    # Eliminate quotation marks
    $l =~ s/\"//g;
  
    # If there's nothing left, call this label h#
    if ($l eq "") { $l = "h#"; }
  
    # write it back to the label array
    $fields[2] = $l;
  }
  # Print the line
  print "@fields\n";
}
